% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotR.R
\name{plotR}
\alias{plotR}
\title{Plot the fitted growth rate dependent on temperature and its density}
\usage{
plotR(
  result = NULL,
  resultmcmc = NULL,
  chain = 1,
  parameters = NULL,
  fixed.parameters = NULL,
  temperatures = NULL,
  curve = "ML quantiles",
  set.par = 1,
  ylim = c(0, 5),
  xlim = c(20, 35),
  hessian = NULL,
  replicate.CI = 1000,
  cex.lab = par("cex"),
  cex.axis = par("cex"),
  scaleY = "auto",
  lty = 1,
  ltyCI = 3,
  lwd = 1,
  lwdCI = 1,
  col = "black",
  col.polygon = "grey",
  polygon = FALSE,
  probs = 0.95,
  colramp = colorRampPalette(c("white", rgb(red = 0.5, green = 0.5, blue = 0.5))),
  bandwidth = c(0.1, 0.01),
  pch = "",
  main = "",
  xlab = expression("Temperature in " * degree * "C"),
  ylab = NULL,
  yaxt = "s",
  bty = "n",
  las = 1,
  by.temperature = 0.1,
  show.density = FALSE,
  new = TRUE,
  show.hist = FALSE,
  ylimH = NULL,
  atH = NULL,
  ylabH = "Temperature density",
  breaks = "Sturges",
  log.hist = FALSE,
  mar = NULL
)
}
\arguments{
\item{result}{A result object or a list of result objects}

\item{resultmcmc}{A result object from GRTN_MHmcmc() function}

\item{chain}{The chain to use in resultmcmc}

\item{parameters}{A set of parameters - Has the priority over result}

\item{fixed.parameters}{A set of fixed parameters}

\item{temperatures}{A set of temperatures - Has the priority over result}

\item{curve}{What curve to show: "MCMC quantiles" or "MCMC mean-SD" based on mcmc or "ML" or "ML quantiles" or "ML mean-SE" for maximum-likelihood. Or "none"}

\item{set.par}{1 or 2 to designate with set of parameters to show}

\item{ylim}{Range of values for y-axis}

\item{xlim}{Range of values for x-axis}

\item{hessian}{An hessian matrix}

\item{replicate.CI}{Number of replicates to estimate confidence interval with Hessian if delta method failed}

\item{cex.lab}{cex value for axis}

\item{cex.axis}{cex value for axis}

\item{scaleY}{Scaling factor for y axis or "auto"}

\item{lty}{The type of lines}

\item{ltyCI}{The type of lines}

\item{lwd}{The type of lines}

\item{lwdCI}{The type of lines}

\item{col}{The color of the lines}

\item{col.polygon}{The color of the polygon}

\item{polygon}{If TRUE, confidence interval is shown as a polygon with color}

\item{probs}{Confidence or credibility interval to show}

\item{colramp}{Ramp function accepting an integer as an argument and returning n colors.}

\item{bandwidth}{numeric vector (length 1 or 2) of smoothing bandwidth(s). If missing, a more or less useful default is used. bandwidth is subsequently passed to function bkde2D.}

\item{pch}{Character for outlayers}

\item{main}{Title of the graph}

\item{xlab}{Label for x axis}

\item{ylab}{Label for y axis}

\item{yaxt}{The yaxt parameter of y-axis}

\item{bty}{Box around the pot}

\item{las}{Orientation for labels in y axis}

\item{by.temperature}{Step to built the temperatures}

\item{show.density}{TRUE or FALSE for use with Hessian or MCMC}

\item{new}{Should the graphics be a new one (TRUE) or superimposed to a previous one (FALSE)}

\item{show.hist}{TRUE or FALSE}

\item{ylimH}{Scale of histogram using ylimH=c(min, max)}

\item{atH}{Position of ticks for scale of histogram}

\item{ylabH}{Label for histogram scale}

\item{breaks}{See ?hist}

\item{log.hist}{SHould the y scale for hist is log ?}

\item{mar}{The value of par("mar"). If null, it will use default depending on show.dist. If NA, does not change par("mar").}
}
\value{
A list with the value of scaleY to be used with other plotR function and the plot data in xy list element
}
\description{
Show the fitted growth rate dependent on temperature and its density.\cr
The curve "ML quantiles" is based on delta method.\cr
The curve "ML" just shows the fitted model.\cr
The curve "MCMC quantiles" uses the mcmc replicates to build the quantiles.\cr
The curve "MCMC mean-SD" uses the mcmc replicates to build a symetric credibility interval.\cr
The parameter curve is case insensitive. If only parameters is given, curve must be ML.
}
\details{
plotR plots the fitted growth rate dependent on temperature and the density of the mcmc
}
\examples{
\dontrun{
library(embryogrowth)
# Note that the confidence interval is not the same for mcmc and ml quantiles
plotR(result = resultNest_4p_SSM, 
             resultmcmc=resultNest_mcmc_4p_SSM, 
             curve = "MCMC quantiles", ylim=c(0, 8))
plotR(resultNest_4p_SSM, curve="ML quantiles", ylim=c(0, 6))
#################
plotR(resultmcmc=resultNest_mcmc_4p_SSM, ylim=c(0, 10), 
             curve = "MCMC quantiles", show.density=TRUE)
#################
plotR(resultmcmc=resultNest_mcmc_4p_SSM, 
             curve = "MCMC quantiles", polygon=TRUE)
#################
plotR(resultmcmc=resultNest_mcmc_6p_SSM, ylim=c(0,8), 
      curve = "MCMC quantiles", polygon=TRUE, col.polygon = rgb(0, 1, 0, 1))
plotR(resultmcmc=resultNest_mcmc_4p_SSM, ylim=c(0,8), 
       curve = "MCMC quantiles", polygon=TRUE, col.polygon = rgb(1, 0, 0, 0.5), 
       new=FALSE)
legend("topleft", legend=c("SSM 4 parameters", "SSM 6 parameters"), 
        pch=c(15, 15), col=c(rgb(1, 0, 0, 0.5), rgb(0, 1, 0, 1)))
#################
sy <- plotR(resultmcmc=resultNest_mcmc_4p_SSM, ylim=c(0, 8), 
             curve = "MCMC quantiles", show.density=FALSE)
plotR(resultmcmc=resultNest_mcmc_6p_SSM, col="red", ylim=c(0, 8), 
             curve = "MCMC quantiles", show.density=FALSE, 
             new=FALSE, scaleY=sy)
#################
sy <- plotR(result=resultNest_6p_SSM, curve="none", 
             scaleY=1E5, 
             ylim=c(0, 8), 
             show.hist = TRUE, new = TRUE, mar=c(4, 4, 1, 4))
#################
plotR(result=resultNest_6p_SSM, curve="ML", 
             ylim=c(0, 8), 
             show.hist = TRUE, ylimH=c(0,1), atH=c(0, 0.1, 0.2))
################
plotR(result = resultNest_4p_SSM, ylim=c(0, 8), 
             resultmcmc=resultNest_mcmc_4p_SSM, 
             show.density = TRUE, 
             curve = "MCMC quantiles")
#################
plotR(resultmcmc=resultNest_mcmc_4p_SSM, ylim=c(0, 8), 
             curve = "MCMC quantiles", show.density=TRUE, scaleY=1E5)
}
}
\author{
Marc Girondot \email{marc.girondot@gmail.com}
}
